@@ -37,7 +37,7 @@
 #include "Whatsapp/util/utilities.h"
 
 #define MAX_MESSAGES               7
-#define LOG_VERSION                3
+#define LOG_VERSION                4
 #define LOG_EXTENSION              ".dblog"
 
 // Column definitions
@@ -61,6 +61,7 @@
 #define LOG_LIVE                    16
 #define LOG_LATITUDE                17
 #define LOG_LONGITUDE               18
+#define LOG_MEDIA_CAPTION           19
 
 ChatLogger::ChatLogger(QObject *parent):
     QObject(parent)
@@ -115,7 +116,8 @@ bool ChatLogger::init(QString jid)
                    "local_file_uri varchar(512),"
                    "live boolean,"
                    "latitude real,"
-                   "longitude real"
+                   "longitude real,"
+                   "media_caption varchar(160)"
                    ")");
 
         query.exec("create table settings ("
@@ -152,6 +154,9 @@ bool ChatLogger::init(QString jid)
                 query.exec();
 
                 version = 2;
+                query.prepare("update settings set version="+
+                              QString::number(version));
+                query.exec();
             }
 
             if (version == 2)
@@ -168,11 +173,26 @@ bool ChatLogger::init(QString jid)
                 query.prepare("alter table log add column longitude real");
                 query.exec();
 
+                version = 3;
                 query.prepare("update settings set version="+
-                              QString::number(LOG_VERSION));
+                              QString::number(version));
+                query.exec();
+            }
+
+            if (version == 3)
+            {
+                // Upgrade it to version 3
+
+                Utilities::logData("Upgrading log " + jid + " to version " +
+                                   QString::number(LOG_VERSION));
+
+                query.prepare("alter table log add column media_caption varchar(160)");
                 query.exec();
 
                 version = LOG_VERSION;
+                query.prepare("update settings set version="+
+                              QString::number(version));
+                query.exec();
             }
         }
 
@@ -196,12 +216,12 @@ void ChatLogger::logMessage(FMessage message)
                   "id, type, data, thumb_image, status, "
                   "media_url, media_mime_type, media_wa_type, media_size, "
                   "media_name, media_duration_seconds, local_file_uri,"
-                  "live, latitude, longitude) "
+                  "live, latitude, longitude, media_caption) "
                   "values (:name, :from_me, :timestamp, :id, "
                   ":type, :data, :thumb_image, :status, "
                   ":media_url, :media_mime_type, :media_wa_type, :media_size, "
                   ":media_name, :media_duration_seconds, :local_file_uri,"
-                  ":live, :latitude, :longitude"
+                  ":live, :latitude, :longitude, :media_caption"
                   ")");
 
     query.bindValue(":name",message.notify_name);
@@ -229,7 +249,7 @@ void ChatLogger::logMessage(FMessage message)
     query.bindValue(":live", message.live);
     query.bindValue(":latitude", message.latitude);
     query.bindValue(":longitude", message.longitude);
-
+    query.bindValue(":media_caption", message.media_caption);	
     query.exec();
 
     Utilities::logData("logMessage(): " + query.lastError().text());
@@ -262,6 +282,7 @@ FMessage ChatLogger::sqlQueryResultToFMessage(QString jid,QSqlQuery& query)
     msg.live = query.value(LOG_LIVE).toBool();
     msg.latitude = query.value(LOG_LATITUDE).toDouble();
     msg.longitude = query.value(LOG_LONGITUDE).toDouble();
+    msg.media_caption = query.value(LOG_MEDIA_CAPTION).toString();
 
 
     if (msg.type == FMessage::MediaMessage)
