@@ -160,8 +160,11 @@ public slots:
     // Sends a query to request the time when a user was last seen online.
     void sendQueryLastOnline(QString jid);
 
+    // Sends a Synchronization request
+    void sendSyncContacts(QStringList numbers);
+
     // Sends a query to get the current status of a user
-    void sendGetStatus(QString jid);
+    void sendGetStatus(QStringList jids);
 
     // Sends a query to request a subscription to a user
     void sendPresenceSubscriptionRequest(QString jid);
@@ -360,14 +363,16 @@ private:
     void sendMessageReceived(FMessage& message);
 
     // Send a notification received acknowledgement
-    void sendNotificationReceived(QString to, QString id);
+    void sendNotificationReceived(QString to, QString id, QString from="",
+                                  QString participant="", QString type="",
+                                  ProtocolTreeNode childNode=ProtocolTreeNode());
 
     // Constructs a receipt acknowledge node
     void getReceiptAck(ProtocolTreeNode& node, QString to, QString id,
                        QString receiptType);
 
     // Sends a receipt acknowledging a delivered message notification received
-    void sendDeliveredReceiptAck(QString to, QString id, QString type);
+    void sendDeliveredReceiptAck(QString to, QString id, QString type="", QString participant="");
 
 
     /** ***********************************************************************
@@ -448,6 +453,17 @@ signals:
     // User status update
     void userStatusUpdated(FMessage message);
 
+    // Contact synchronized
+    void contactSync(QString jid, QString phone);
+
+    // Contact deleted
+    void contactDeleted(QString jid, QString phone);
+
+    // Contact Synchronization failed
+    void syncError();
+
+    // Status
+    void statusChanged(QString jid, qint64 t, QString status);
 
     /** ***********************************************************************
      ** Picture handling
